utils

package
v0.0.0-...-0149f20 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExecCommand

func ExecCommand(bfr io.Writer, args ...string) error

ExecCommand executes an os shell command

func GetClientOutOfCluster

func GetClientOutOfCluster() kubernetes.Interface

GetClientOutOfCluster returns a k8s clientset to the request from outside of cluster

func RunPrompt

func RunPrompt(ctxs []string, label string) (string, error)

RunPrompt prompts the use with options on the terminal

Types

This section is empty.

Jump to